aboutsummaryrefslogtreecommitdiff
path: root/src/sqliteInt.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/sqliteInt.h')
-rw-r--r--src/sqliteInt.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/sqliteInt.h b/src/sqliteInt.h
index 002fb4e91..35074ee81 100644
--- a/src/sqliteInt.h
+++ b/src/sqliteInt.h
@@ -1365,8 +1365,9 @@ struct sqlite3 {
int newTnum; /* Rootpage of table being initialized */
u8 iDb; /* Which db file is being initialized */
u8 busy; /* TRUE if currently initializing */
- u8 orphanTrigger; /* Last statement is orphaned TEMP trigger */
- u8 imposterTable; /* Building an imposter table */
+ u8 orphanTrigger : 1; /* Last statement is orphaned TEMP trigger */
+ u8 imposterTable : 1; /* Building an imposter table */
+ u8 reopenMemdb : 1; /* ATTACH is really a reopen using MemDB */
} init;
int nVdbeActive; /* Number of VDBEs currently running */
int nVdbeRead; /* Number of active VDBEs that read or write */